@@ -1,3 +1,5 @@
+from unittest import mock
+
 from django.db import connection, transaction
 from django.db.models import Case, Count, F, FilteredRelation, Q, When
 from django.test import TestCase
@@ -335,6 +337,9 @@ class FilteredRelationTests(TestCase):
             [self.book1]
         )
 
+    def test_eq(self):
+        self.assertEqual(FilteredRelation('book', condition=Q(book__title='b')), mock.ANY)
+
 
 class FilteredRelationAggregationTests(TestCase):
 
