@@ -1,13 +1,3 @@
-"""
-XX. Generating HTML forms from models
-
-This is mostly just a reworking of the ``form_for_model``/``form_for_instance``
-tests to use ``ModelForm``. As such, the text may not make sense in all cases,
-and the examples are probably a poor fit for the ``ModelForm`` syntax. In other
-words, most of these tests should be rewritten.
-"""
-from __future__ import unicode_literals
-
 import datetime
 import os
 import tempfile
@@ -17,32 +7,15 @@ from django.core import validators
 from django.core.exceptions import ValidationError
 from django.core.files.storage import FileSystemStorage
 from django.db import models
-from django.utils import six
-from django.utils._os import upath
-from django.utils.encoding import python_2_unicode_compatible
-from django.utils.six.moves import range
 
 temp_storage_dir = tempfile.mkdtemp()
 temp_storage = FileSystemStorage(temp_storage_dir)
 
-ARTICLE_STATUS = (
-    (1, 'Draft'),
-    (2, 'Pending'),
-    (3, 'Live'),
-)
-
-ARTICLE_STATUS_CHAR = (
-    ('d', 'Draft'),
-    ('p', 'Pending'),
-    ('l', 'Live'),
-)
-
 
 class Person(models.Model):
     name = models.CharField(max_length=100)
 
 
-@python_2_unicode_compatible
 class Category(models.Model):
     name = models.CharField(max_length=20)
     slug = models.SlugField(max_length=20)
@@ -55,7 +28,6 @@ class Category(models.Model):
         return self.__str__()
 
 
-@python_2_unicode_compatible
 class Writer(models.Model):
     name = models.CharField(max_length=50, help_text='Use both first and last names.')
 
@@ -66,8 +38,12 @@ class Writer(models.Model):
         return self.name
 
 
-@python_2_unicode_compatible
 class Article(models.Model):
+    ARTICLE_STATUS = (
+        (1, 'Draft'),
+        (2, 'Pending'),
+        (3, 'Live'),
+    )
     headline = models.CharField(max_length=50)
     slug = models.SlugField()
     pub_date = models.DateField()
@@ -80,7 +56,7 @@ class Article(models.Model):
     def save(self, *args, **kwargs):
         if not self.id:
             self.created = datetime.date.today()
-        return super(Article, self).save(*args, **kwargs)
+        return super().save(*args, **kwargs)
 
     def __str__(self):
         return self.headline
@@ -98,7 +74,6 @@ class BetterWriter(Writer):
     score = models.IntegerField()
 
 
-@python_2_unicode_compatible
 class Publication(models.Model):
     title = models.CharField(max_length=30)
     date_published = models.DateField()
@@ -120,8 +95,11 @@ class PublicationDefaults(models.Model):
     CATEGORY_CHOICES = ((1, 'Games'), (2, 'Comics'), (3, 'Novel'))
     title = models.CharField(max_length=30)
     date_published = models.DateField(default=datetime.date.today)
+    datetime_published = models.DateTimeField(default=datetime.datetime(2000, 1, 1))
     mode = models.CharField(max_length=2, choices=MODE_CHOICES, default=default_mode)
     category = models.IntegerField(choices=CATEGORY_CHOICES, default=default_category)
+    active = models.BooleanField(default=True)
+    file = models.FileField(default='default.txt')
 
 
 class Author(models.Model):
@@ -130,11 +108,10 @@ class Author(models.Model):
 
 
 class Author1(models.Model):
-    publication = models.OneToOneField(Publication, models.SET_NULL, null=False)
+    publication = models.OneToOneField(Publication, models.CASCADE, null=False)
     full_name = models.CharField(max_length=255)
 
 
-@python_2_unicode_compatible
 class WriterProfile(models.Model):
     writer = models.OneToOneField(Writer, models.CASCADE, primary_key=True)
     age = models.PositiveIntegerField()
@@ -147,7 +124,6 @@ class Document(models.Model):
     myfile = models.FileField(upload_to='unused', blank=True)
 
 
-@python_2_unicode_compatible
 class TextFile(models.Model):
     description = models.CharField(max_length=20)
     file = models.FileField(storage=temp_storage, upload_to='tests', max_length=15)
@@ -168,7 +144,7 @@ class CustomFF(models.Model):
 
 
 class FilePathModel(models.Model):
-    path = models.FilePathField(path=os.path.dirname(upath(__file__)), match=".*\.py$", blank=True)
+    path = models.FilePathField(path=os.path.dirname(__file__), match='models.py', blank=True)
 
 
 try:
@@ -176,7 +152,6 @@ try:
 
     test_images = True
 
-    @python_2_unicode_compatible
     class ImageFile(models.Model):
         def custom_upload_path(self, filename):
             path = self.path or 'tests'
@@ -195,7 +170,6 @@ try:
         def __str__(self):
             return self.description
 
-    @python_2_unicode_compatible
     class OptionalImageFile(models.Model):
         def custom_upload_path(self, filename):
             path = self.path or 'tests'
@@ -211,23 +185,25 @@ try:
 
         def __str__(self):
             return self.description
+
+    class NoExtensionImageFile(models.Model):
+        def upload_to(self, filename):
+            return 'tests/no_extension'
+
+        description = models.CharField(max_length=20)
+        image = models.ImageField(storage=temp_storage, upload_to=upload_to)
+
+        def __str__(self):
+            return self.description
+
 except ImportError:
     test_images = False
 
 
-@python_2_unicode_compatible
-class CommaSeparatedInteger(models.Model):
-    field = models.CommaSeparatedIntegerField(max_length=20)
-
-    def __str__(self):
-        return self.field
-
-
 class Homepage(models.Model):
     url = models.URLField()
 
 
-@python_2_unicode_compatible
 class Product(models.Model):
     slug = models.SlugField(unique=True)
 
@@ -235,17 +211,16 @@ class Product(models.Model):
         return self.slug
 
 
-@python_2_unicode_compatible
 class Price(models.Model):
     price = models.DecimalField(max_digits=10, decimal_places=2)
     quantity = models.PositiveIntegerField()
 
-    def __str__(self):
-        return "%s for %s" % (self.quantity, self.price)
-
     class Meta:
         unique_together = (('price', 'quantity'),)
 
+    def __str__(self):
+        return "%s for %s" % (self.quantity, self.price)
+
 
 class Triple(models.Model):
     left = models.IntegerField()
@@ -257,10 +232,14 @@ class Triple(models.Model):
 
 
 class ArticleStatus(models.Model):
+    ARTICLE_STATUS_CHAR = (
+        ('d', 'Draft'),
+        ('p', 'Pending'),
+        ('l', 'Live'),
+    )
     status = models.CharField(max_length=2, choices=ARTICLE_STATUS_CHAR, blank=True, null=True)
 
 
-@python_2_unicode_compatible
 class Inventory(models.Model):
     barcode = models.PositiveIntegerField(unique=True)
     parent = models.ForeignKey('self', models.SET_NULL, to_field='barcode', blank=True, null=True)
@@ -299,7 +278,6 @@ class DerivedBook(Book, BookXtra):
     pass
 
 
-@python_2_unicode_compatible
 class ExplicitPK(models.Model):
     key = models.CharField(max_length=20, primary_key=True)
     desc = models.CharField(max_length=20, blank=True, unique=True)
@@ -311,7 +289,6 @@ class ExplicitPK(models.Model):
         return self.key
 
 
-@python_2_unicode_compatible
 class Post(models.Model):
     title = models.CharField(max_length=50, unique_for_date='posted', blank=True)
     slug = models.CharField(max_length=50, unique_for_year='posted', blank=True)
@@ -322,7 +299,6 @@ class Post(models.Model):
         return self.title
 
 
-@python_2_unicode_compatible
 class DateTimePost(models.Model):
     title = models.CharField(max_length=50, unique_for_date='posted', blank=True)
     slug = models.CharField(max_length=50, unique_for_year='posted', blank=True)
@@ -337,18 +313,17 @@ class DerivedPost(Post):
     pass
 
 
-@python_2_unicode_compatible
 class BigInt(models.Model):
     biggie = models.BigIntegerField()
 
     def __str__(self):
-        return six.text_type(self.biggie)
+        return str(self.biggie)
 
 
 class MarkupField(models.CharField):
     def __init__(self, *args, **kwargs):
         kwargs["max_length"] = 20
-        super(MarkupField, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
     def formfield(self, **kwargs):
         # don't allow this field to be used in form (real use-case might be
@@ -370,13 +345,11 @@ class FlexibleDatePost(models.Model):
     posted = models.DateField(blank=True, null=True)
 
 
-@python_2_unicode_compatible
 class Colour(models.Model):
     name = models.CharField(max_length=50)
 
     def __iter__(self):
-        for number in range(5):
-            yield number
+        yield from range(5)
 
     def __str__(self):
         return self.name
@@ -388,13 +361,16 @@ class ColourfulItem(models.Model):
 
 
 class CustomErrorMessage(models.Model):
-    name1 = models.CharField(max_length=50,
+    name1 = models.CharField(
+        max_length=50,
         validators=[validators.validate_slug],
-        error_messages={'invalid': 'Model custom error message.'})
-
-    name2 = models.CharField(max_length=50,
+        error_messages={'invalid': 'Model custom error message.'},
+    )
+    name2 = models.CharField(
+        max_length=50,
         validators=[validators.validate_slug],
-        error_messages={'invalid': 'Model custom error message.'})
+        error_messages={'invalid': 'Model custom error message.'},
+    )
 
     def clean(self):
         if self.name1 == 'FORBIDDEN_VALUE':
@@ -417,6 +393,9 @@ class Character(models.Model):
     username = models.CharField(max_length=100)
     last_action = models.DateTimeField()
 
+    def __str__(self):
+        return self.username
+
 
 class StumpJoke(models.Model):
     most_recently_fooled = models.ForeignKey(
@@ -442,11 +421,11 @@ class Photo(models.Model):
     # Support code for the tests; this keeps track of how many times save()
     # gets called on each instance.
     def __init__(self, *args, **kwargs):
-        super(Photo, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self._savecount = 0
 
     def save(self, force_insert=False, force_update=False):
-        super(Photo, self).save(force_insert, force_update)
+        super().save(force_insert, force_update)
         self._savecount += 1
 
 
@@ -463,7 +442,7 @@ class StrictAssignmentFieldSpecific(models.Model):
     def __setattr__(self, key, value):
         if self._should_error is True:
             raise ValidationError(message={key: "Cannot set attribute"}, code='invalid')
-        super(StrictAssignmentFieldSpecific, self).__setattr__(key, value)
+        super().__setattr__(key, value)
 
 
 class StrictAssignmentAll(models.Model):
@@ -473,4 +452,14 @@ class StrictAssignmentAll(models.Model):
     def __setattr__(self, key, value):
         if self._should_error is True:
             raise ValidationError(message="Cannot set attribute", code='invalid')
-        super(StrictAssignmentAll, self).__setattr__(key, value)
+        super().__setattr__(key, value)
+
+
+# A model with ForeignKey(blank=False, null=True)
+class Award(models.Model):
+    name = models.CharField(max_length=30)
+    character = models.ForeignKey(Character, models.SET_NULL, blank=False, null=True)
+
+
+class NullableUniqueCharFieldModel(models.Model):
+    codename = models.CharField(max_length=50, blank=True, null=True, unique=True)
